===========================
 API Reference
===========================

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 2

    kombu.connection
    kombu.simple
    kombu.messaging
    kombu.entity
    kombu.common
    kombu.mixins
    kombu.clocks
    kombu.compat
    kombu.pidbox
    kombu.exceptions
    kombu.log
    kombu.transport
    kombu.transport.amqplib
    kombu.transport.librabbitmq
    kombu.transport.pika
    kombu.transport.pika2
    kombu.transport.memory
    kombu.transport.redis
    kombu.transport.beanstalk
    kombu.transport.mongodb
    kombu.transport.couchdb
    kombu.transport.django
    kombu.transport.django.models
    kombu.transport.django.managers
    kombu.transport.django.management.commands.clean_kombu_messages
    kombu.transport.sqlalchemy
    kombu.transport.sqlalchemy.models
    kombu.transport.SQS
    kombu.transport.base
    kombu.transport.virtual
    kombu.transport.virtual.exchange
    kombu.transport.virtual.scheduling
    kombu.serialization
    kombu.compression
    kombu.pools
    kombu.abstract
    kombu.syn
    kombu.utils
    kombu.utils.limits
    kombu.utils.compat
    kombu.utils.debug
    kombu.utils.encoding
    kombu.utils.functional
    kombu.utils.finalize
